<h1 align="center">
    <br>
        <img src="https://gofile.io/dist/img/logo-big.png" alt="GoFile" width="400">
    <br>
    <br>
        GoFile API for Python3
    <br>
</h1>

<h4 align="center">Simple module to use the <a href="https://gofile.io" target="_blank">GoFile</a> API in Python3.</h4>

<p align='center'>
    <a href='https://github.com/Micky014/gofile/master/LICENSE'>
        <img alt="GitHub" src="https://img.shields.io/github/license/Micky014/gofile">
    </a>
</p>

<p align="center">
  <a href="#how-to-use">How to use</a> •
  <a href="#example">Example</a> •
  <a href="https://github.com/Micky014/gofile/wiki">Documentation</a>
</p>

## How To Use

To use this module you need to have [python](https://www.python.org/downloads) (3.7 or higher) and the [pip](https://pip.pypa.io/en/stable/installation/) package manager installed. 

```bash
# Install the module
$ pip install pygofile
```

## Example
Basic example of how the module works, to read the documentation, go to the [wiki](https://github.com/Micky014/gofile/wiki).

<p align="center">
    <img src='examples/example.png'>
</p>

<!-- > **Note**
> If you're using Linux Bash for Windows, [see this guide](https://www.howtogeek.com/261575/how-to-run-graphical-linux-desktop-applications-from-windows-10s-bash-shell/) or use `node` from the command prompt. -->

---

